mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* [PATCH] [trivial] powernv: Fix typo in opal-flash.c
@ 2013-12-23 20:51 Hayato Suzuki
  0 siblings, 0 replies; only message in thread
From: Hayato Suzuki @ 2013-12-23 20:51 UTC (permalink / raw)
  To: trivial; +Cc: linux-kernel, Hayato Suzuki

Correct spelling typo in opal-flash.c

Signed-off-by: Hayato Suzuki <hytszk@gmail.com>
---
 arch/powerpc/platforms/powernv/opal-flash.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/arch/powerpc/platforms/powernv/opal-flash.c b/arch/powerpc/platforms/powernv/opal-flash.c
index 4aeae4f..d8f67ba 100644
--- a/arch/powerpc/platforms/powernv/opal-flash.c
+++ b/arch/powerpc/platforms/powernv/opal-flash.c
@@ -105,7 +105,7 @@ struct image_header_t {
 
 struct validate_flash_t {
 	int		status;		/* Return status */
-	void		*buf;		/* Candiate image buffer */
+	void		*buf;		/* Candidate image buffer */
 	uint32_t	buf_size;	/* Image size */
 	uint32_t	result;		/* Update results token */
 };
@@ -481,7 +481,7 @@ static int alloc_image_buf(char *buffer, size_t count)
 
 	memcpy(&image_header, (void *)buffer, sizeof(struct image_header_t));
 	image_data.size = be32_to_cpu(image_header.size);
-	pr_debug("FLASH: Candiate image size = %u\n", image_data.size);
+	pr_debug("FLASH: Candidate image size = %u\n", image_data.size);
 
 	if (image_data.size > MAX_IMAGE_SIZE) {
 		pr_warn("FLASH: Too large image\n");
-- 
1.8.4.2


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2013-12-23 20:51 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2013-12-23 20:51 [PATCH] [trivial] powernv: Fix typo in opal-flash.c Hayato Suzuki

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®